@@ -26,14 +26,11 @@
 #include "utils.h"
 
 #include <QGridLayout>
-#include <QRegExp>
 
 #include <kactioncollection.h>
 #include "akregator_debug.h"
 #include <KLocalizedString>
 #include <QUrl>
-#include <kparts/browserextension.h>
-#include <kparts/part.h>
 
 #include <Libkdepim/ProgressManager>
 
@@ -207,4 +204,3 @@ int Frame::progress() const
 {
     return m_progress;
 }
-
