@@ -34,8 +34,6 @@
 #include <kprocess.h>
 #include <kshell.h>
 #include <kconfiggroup.h>
-#include <kparts/event.h>
-#include <kparts/guiactivateevent.h>
 #include "akregator_debug.h"
 #include <webengine/webengineframe.h>
 #include <QStringList>
@@ -45,8 +43,8 @@
 using namespace Akregator;
 
 FrameManager::FrameManager(QObject *parent)
-    : QObject(parent),
-      m_currentFrame(0)
+    : QObject(parent)
+    , m_currentFrame(nullptr)
 {
 }
 
@@ -80,7 +78,6 @@ void FrameManager::slotAddFrame(Frame *frame)
     if (m_frames.count() == 1) {
         slotChangeFrame(frame->id());
     }
-
 }
 
 void FrameManager::slotRemoveFrame(int id)
@@ -205,10 +202,6 @@ void FrameManager::slotSetStatusText(Frame *frame, const QString &statusText)
 
 void FrameManager::openUrl(OpenUrlRequest &request)
 {
-    if (!m_currentFrame) {
-        return;
-    }
-
     if (request.browserArgs().newTab() || request.browserArgs().forcesNewWindow() || request.options() == OpenUrlRequest::NewTab || (m_currentFrame->id() == 0)) {
         int newFrameId = -1;
         Q_EMIT signalRequestNewFrame(newFrameId);
@@ -264,10 +257,10 @@ void FrameManager::slotOpenUrlRequest(OpenUrlRequest &request, bool useOpenInBac
 
     if (useOpenInBackgroundSetting) {
         // Honour user's preference for foreground/background tabs
-        if (request.options() == OpenUrlRequest::NewTab ||
-                request.browserArgs().newTab()) {
-            request.setOpenInBackground(Settings::lMBBehaviour() ==
-                                        Settings::EnumLMBBehaviour::OpenInBackground);
+        if (request.options() == OpenUrlRequest::NewTab
+            || request.browserArgs().newTab()) {
+            request.setOpenInBackground(Settings::lMBBehaviour()
+                                        == Settings::EnumLMBBehaviour::OpenInBackground);
         }
     }
     openUrl(request);
