@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -24,8 +24,7 @@
 #include "akregatorpart_export.h"
 #include <QObject>
 
-namespace Akregator
-{
+namespace Akregator {
 class ArticleViewerWebEngineWidgetNg;
 class AKREGATORPART_EXPORT WebEngineFrame : public Frame
 {
@@ -34,16 +33,16 @@ public:
     explicit WebEngineFrame(KActionCollection *ac, QWidget *parent = nullptr);
     ~WebEngineFrame();
 
-    QUrl url() const Q_DECL_OVERRIDE;
-    bool openUrl(const OpenUrlRequest &request) Q_DECL_OVERRIDE;
-    void loadConfig(const KConfigGroup &, const QString &) Q_DECL_OVERRIDE;
-    bool saveConfig(KConfigGroup &, const QString &) Q_DECL_OVERRIDE;
+    QUrl url() const override;
+    bool openUrl(const OpenUrlRequest &request) override;
+    void loadConfig(const KConfigGroup &, const QString &) override;
+    bool saveConfig(KConfigGroup &, const QString &) override;
 
-    qreal zoomFactor() const Q_DECL_OVERRIDE;
+    qreal zoomFactor() const override;
 
 public Q_SLOTS:
-    void slotReload() Q_DECL_OVERRIDE;
-    void slotStop() Q_DECL_OVERRIDE;
+    void slotReload() override;
+    void slotStop() override;
 
     void slotZoomChangeInFrame(int frameId, qreal value);
     void slotCopyInFrame(int frameId);
